/* ----------------------------------------------------------------------------
 * Copyright (c) 2016 Semiconductor Components Industries, LLC (d/b/a
 * ON Semiconductor), All Rights Reserved
 *
 * This code is the property of ON Semiconductor and may not be redistributed
 * in any form without prior written permission from ON Semiconductor.
 * The terms of use and warranty for this code are covered by contractual
 * agreements between ON Semiconductor and the licensee.
 * ----------------------------------------------------------------------------
 * app.c
 * - Main application file
 * ----------------------------------------------------------------------------
 * $Revision: 1.65 $
 * $Date: 2017/12/01 17:42:47 $
 * ------------------------------------------------------------------------- */

#include "include/app.h"


int main() {

	App_Initialize();
	/* Main application loop */
	Main_Loop();
}

/* ----------------------------------------------------------------------------
 * Function      : Main_Loop(void)
 * ----------------------------------------------------------------------------
 * Description   : - Run the kernel scheduler
 *                 - Update the battery voltage when applicable
 *                 - Update custom service data when applicable
 *                 - Attempt to go to sleep mode if possible
 * Inputs        : None
 * Outputs       : None
 * Assumptions   : None
 * ------------------------------------------------------------------------- */
void Main_Loop(void) {
	Sys_Watchdog_Refresh();
    Sys_DIO_Config(10, DIO_MODE_GPIO_OUT_1);
	/* Configure ADC channel 0 to measure VBAT/2 */
	Sys_ADC_Set_Config(
			ADC_VBAT_DIV2_NORMAL | ADC_NORMAL | ADC_PRESCALE_200);
	Sys_ADC_InputSelectConfig(0,
			(ADC_NEG_INPUT_GND | ADC_POS_INPUT_VBAT_DIV2));
	/* Wait for ADC to measure voltage */
	Sys_Delay_ProgramROM(2000);
	/* Read the battery level and update the average value */
	Measure_Battery_Level();

	Sys_ADC_Set_Config(ADC_DISABLE);

	ble_env.adv_count++;

	Advertising_Update();
    Sys_DIO_Config(10, DIO_MODE_GPIO_OUT_0);
	while (true) {
		Kernel_Schedule();
		Sys_Watchdog_Refresh();
		GLOBAL_INT_DISABLE();
		BLE_Power_Mode_Enter(&sleep_mode_env, POWER_MODE_SLEEP);
		GLOBAL_INT_RESTORE();
	}

	/* Wait for an interrupt before executing the scheduler again */
	SYS_WAIT_FOR_INTERRUPT;

}
